[![HitCount](http://hits.dwyl.io/debdutgoswami/instagram-profile-picture.svg)](http://hits.dwyl.io/debdutgoswami/instagram-profile-picture)

# Instagram Profile Picture Extraction

I have used python to open and also download Instagram profile pictures as because Instagram does not allow us to open the picture.

## use

Clone the repository and run the ```main.py``` file and enter a valid `username` as input.

## requirements

For running this, you need to have python3 installed in your system.

after that run the command
**pip install -r requirements.txt**

This will install all the necessary libraries required for this.

## Official website

Instagram Profile Picture: [Official website](http://instaprofilepic.appspot.com/)
